#!/bin/bash

#
#Startup script for gateway
#

#
# PID file
#
PID=/var/run/unicore/gateway.pid

#
# Startup log
#
STARTLOG=/var/log/unicore/gateway/startup.log

INST=/etc/unicore/gateway
cd $INST

#
# check whether the server might be already running
#
if [ -e $PID ] 
 then 
  if [ -d /proc/$(cat $PID) ]
   then
     echo "A Gateway instance may be already running with process id "$(cat $PID)
     echo "If this is not the case, delete the file $INST/$PID and re-run this script"
     exit 1
   fi
fi


#
#Java command 
#
JAVA=java


#
#Options to the Java VM
#

#set this one if you have ssl problems and need debug info
#OPTS=$OPTS" -Djavax.net.debug=ssl,handshake"

#logging configuration file
OPTS=$OPTS" -Djava.util.logging.config.file=/etc/unicore/gateway/logging.properties"
OPTS=$OPTS" -Dlog4j.configuration=file:///etc/unicore/gateway/logging.properties"

#
#enable JMX (use jconsole to connect)
#
#OPTS=$OPTS" -Dcom.sun.management.jmxremote"
#enable JMX remote access protected by username/password
#OPTS=$OPTS" -Dcom.sun.management.jmxremote.port=9132 -Dcom.sun.management.jmxremote.authenticate=true"
#OPTS=$OPTS" -Dcom.sun.management.jmxremote.ssl=false"
#OPTS=$OPTS" -Dcom.sun.management.jmxremote.password.file=jmxremote.password"

#
# CRL checker config file
OPTS=$OPTS" -Dcrlmanager.properties.file=crlcheck.properties"

# endorsed libs
OPTS=${OPTS}" -Djava.endorsed.dirs=/usr/share/unicore/gateway/lib/endorsed"

#
#Memory for the VM
#
MEM=-Xmx128m

#
#put all jars in lib/ on the classpath
#
JARS=/usr/share/unicore/gateway/lib/*.jar
CP=
for JAR in $JARS ; do 
    CP=$CP:$JAR
done

#
# Parameters, such as config file locations
#
PARAM="gateway.properties connections.properties security.properties"

#
#go
#
export CLASSPATH=$CP
nohup $JAVA ${MEM} ${OPTS} ${DEFS} eu.unicore.gateway.Gateway ${PARAM} > $STARTLOG 2>&1  &
echo $! > $PID




