package eu.unicore.gateway;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;

import org.apache.commons.httpclient.HttpStatus;
import org.apache.log4j.Logger;

import eu.unicore.gateway.util.LogUtil;

/**
 * a fake server replying to HTTP requests
 */
public class FakeServer implements Runnable {
	
	private static final Logger log = LogUtil.getLogger(LogUtil.GATEWAY,FakeServer.class);

	private final int port;
	
	private ServerSocket serverSocket;

	private volatile boolean stopping=false;
	
	private volatile boolean stopped=false;
	
	private volatile int statusCode=200;
	
	/**
	 * creates a FakeServer listening on the given port
	 * @param port
	 * @throws IOException
	 */
	public FakeServer(int port)throws IOException{
		serverSocket=new ServerSocket(port);
		serverSocket.setSoTimeout(5000);
		this.port=serverSocket.getLocalPort();
	}

	/**
	 * creates a FakeServer listening on a free port
	 * @see getPort()
	 */
	public FakeServer()throws IOException{
		this(0);
	}
	
	public String getURI(){
		return "http://localhost:"+port;
	}
	
	private static int n=0;
	public synchronized void start(){
		Thread t=new Thread(this);
		t.setName("FakeVSiteListenerThread"+(n++));
		t.start();
	}
	
	public synchronized void restart()throws Exception{
		if(serverSocket!=null)throw new IllegalStateException();
		
		serverSocket=new ServerSocket(port);
		stopping=false;
		stopped=false;
		start();
	}
	
	public void stop(){
		stopping=true;
	}
	
	public boolean isStopped(){
		return stopped;
	}

	private final String answer="Everything is OK, thank you for contacting me.";
	
	public void run(){
		while(!stopping){
			try{
				Socket socket=serverSocket.accept();
				
				byte[]buf=new byte[2048];
				socket.getInputStream().read(buf);
				String status="HTTP/1.1 "+statusCode+" "+HttpStatus.getStatusText(statusCode);
				String reply="\nContent-Length: "+answer.length()+"\n\n"+answer;
				socket.getOutputStream().write(status.getBytes());
				socket.getOutputStream().write(reply.getBytes());
				System.out.println("HANDLING REQUEST, returning "+status);
				socket.close();
			}catch(Exception ex){

			}
		}
		log.info("Stopped.");
		stopped=true;
		try{
			serverSocket.close();
		}catch(IOException e){/*ignored*/}
		serverSocket=null;
	}
	
	public int getPort(){
		return port;
	}
	
	public void setStatusCode(int statusCode){
		this.statusCode=statusCode;
	}
}
